DJANGO_SPIRE_AUTH_CONTROLLERS = {
    'ai_chat': 'django_spire.ai.chat.auth.controller.BaseAiChatAuthController',
    'knowledge': 'django_spire.knowledge.auth.controller.BaseKnowledgeAuthController'
}
